source("modules/Loading/Loading.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")

recipe_file <- "recipes/tests/recipe_seasonal_two-variables.yml"
recipe <- prepare_outputs(recipe_file, disable_checks = T)
atomic_recipes <- divide_recipe(recipe)
## archive <- read_yaml(paste0(recipe$Run$code_dir, "conf/archive.yml"))$archive

for (atomic_recipe in atomic_recipes) {
  # Load datasets
  data <- load_datasets(atomic_recipe)
  # Calibrate datasets
  calibrated_data <- calibrate_datasets(atomic_recipe, data)
  # Compute anomalies
  calibrated_data <- compute_anomalies(atomic_recipe, calibrated_data)
  # Compute skill metrics 
  skill_metrics <- compute_skill_metrics(atomic_recipe, calibrated_data)
  # Compute percentiles and probability bins
  probabilities <- compute_probabilities(atomic_recipe, calibrated_data)
  # Export all data to netCDF
  save_data(atomic_recipe, calibrated_data, skill_metrics, probabilities)
  # Plot data
  plot_data(atomic_recipe, calibrated_data, skill_metrics, probabilities,
	    significance = T)
}
